aboutsummaryrefslogtreecommitdiffstats
path: root/sdnr/wt/odlux/apps/performanceHistoryApp/src/models/performanceDataType.ts
diff options
context:
space:
mode:
Diffstat (limited to 'sdnr/wt/odlux/apps/performanceHistoryApp/src/models/performanceDataType.ts')
-rw-r--r--sdnr/wt/odlux/apps/performanceHistoryApp/src/models/performanceDataType.ts64
1 files changed, 54 insertions, 10 deletions
diff --git a/sdnr/wt/odlux/apps/performanceHistoryApp/src/models/performanceDataType.ts b/sdnr/wt/odlux/apps/performanceHistoryApp/src/models/performanceDataType.ts
index 3c9b5cb21..6af29c4a8 100644
--- a/sdnr/wt/odlux/apps/performanceHistoryApp/src/models/performanceDataType.ts
+++ b/sdnr/wt/odlux/apps/performanceHistoryApp/src/models/performanceDataType.ts
@@ -1,19 +1,63 @@
-export { HitEntry, Result } from '../../../../framework/src/models';
+/**
+ * ============LICENSE_START========================================================================
+ * ONAP : ccsdk feature sdnr wt odlux
+ * =================================================================================================
+ * Copyright (C) 2019 highstreet technologies GmbH Intellectual Property. All rights reserved.
+ * =================================================================================================
+ * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except
+ * in compliance with the License. You may obtain a copy of the License at
+ *
+ * http://www.apache.org/licenses/LICENSE-2.0
+ *
+ * Unless required by applicable law or agreed to in writing, software distributed under the License
+ * is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express
+ * or implied. See the License for the specific language governing permissions and limitations under
+ * the License.
+ * ============LICENSE_END==========================================================================
+ */
+import { Moment } from "moment";
+
+//export { HitEntry, Result } from '../../../../framework/src/models';
/**
* Represents performance data fields of the performance history table.
*/
-export type PerformanceDataType = {
- "_id": string;
+export type PerformanceDatabaseDataType = {
+ "es": number;
+ "ses": number;
+ "unavailability": number;
+};
+
+
+/**
+ * Represents Result type of database query
+ */
+export type PerformanceResult = {
+ "performance-data": PerformanceDatabaseDataType;
"radio-signal-id": string;
"scanner-id": string;
- "time-stamp": string;
"suspect-interval-flag": boolean;
- "es": string;
- "ses": string;
- "unavailability": string;
+ "time-stamp": string;
};
-export type PerformanceResult = { "performance-data": PerformanceDataType };
+/**
+ * Internally used type to provide table and chart data
+ */
+export type PerformanceDataType = {
+ radioSignalId: string;
+ scannerId: string;
+ utcTimeStamp: string;
+ suspectIntervalFlag: boolean;
+ es: number;
+ ses: number;
+ unavailability: number;
+} & { _id: string };
+
-export type Performance = PerformanceDataType & { _id: string }; \ No newline at end of file
+/**
+ * Represents performance data time interval.
+ */
+export const enum PmDataInterval {
+ pmInterval15Min,
+ pmInterval24Hours
+} \ No newline at end of file
@@ -1,19 +1,63 @@
/**
- * Represents performance data fields of the performance history table.
+ * Represents performance data fields of the performance history table as used in the database
*/